@@ -611,12 +611,21 @@ void Part::loadArchive()
     }
 }
 
+void Part::resetArchive()
+{
+    m_view->setDropsEnabled(false);
+    m_model->reset();
+    closeUrl();
+    setFileNameFromArchive();
+    updateActions();
+}
+
 void Part::resetGui()
 {
     m_messageWidget->hide();
     m_commentView->clear();
     m_commentBox->hide();
-    m_infoPanel->setIndex(QModelIndex());
+    m_infoPanel->updateWithDefaults();
     // Also reset format-specific compression options.
     m_compressionOptions = CompressionOptions();
 }
@@ -724,7 +733,8 @@ void Part::selectionChanged()
 QModelIndexList Part::getSelectedIndexes()
 {
     QModelIndexList list;
-    foreach (const QModelIndex &i, m_view->selectionModel()->selectedRows()) {
+    const auto selectedRows = m_view->selectionModel()->selectedRows();
+    for (const QModelIndex &i : selectedRows) {
         list.append(m_filterModel->mapToSource(i));
     }
     return list;
@@ -912,11 +922,8 @@ void Part::slotLoadingFinished(KJob *job)
 
     // Loading failed or was canceled by the user (e.g. password dialog rejected).
     emit canceled(job->errorString());
-    m_view->setDropsEnabled(false);
-    m_model->reset();
-    closeUrl();
-    setFileNameFromArchive();
-    updateActions();
+    resetArchive();
+
     if (job->error() != KJob::KilledJobError) {
         displayMsgWidget(KMessageWidget::Error, xi18nc("@info", "Loading the archive <filename>%1</filename> failed with the following error:<nl/><message>%2</message>",
                                                        localFilePath(),
@@ -1058,7 +1065,7 @@ void Part::slotWatchedFileModified(const QString& file)
 
     // Find the relative path of the file within the archive.
     QString relPath = file;
-    foreach (QTemporaryDir *tmpDir, m_tmpExtractDirList) {
+    for (QTemporaryDir *tmpDir : qAsConst(m_tmpExtractDirList)) {
         relPath.remove(tmpDir->path()); //Remove tmpDir.
     }
     relPath = relPath.mid(1); //Remove leading slash.
@@ -1196,7 +1203,7 @@ QVector<Archive::Entry*> Part::filesForIndexes(const QModelIndexList& list) cons
 {
     QVector<Archive::Entry*> ret;
 
-    foreach(const QModelIndex& index, list) {
+    for (const QModelIndex& index : list) {
         ret << m_model->entryForIndex(index);
     }
 
@@ -1208,7 +1215,7 @@ QVector<Kerfuffle::Archive::Entry*> Part::filesAndRootNodesForIndexes(const QMod
     QVector<Kerfuffle::Archive::Entry*> fileList;
     QStringList fullPathsList;
 
-    foreach (const QModelIndex& index, list) {
+    for (const QModelIndex& index : list) {
 
         // Find the topmost unselected parent. This is done by iterating up
         // through the directory hierarchy and see if each parent is included
@@ -1229,7 +1236,8 @@ QVector<Kerfuffle::Archive::Entry*> Part::filesAndRootNodesForIndexes(const QMod
 
         // Append index with root node to fileList.
         QModelIndexList alist = QModelIndexList() << index;
-        foreach (Archive::Entry *entry, filesForIndexes(alist)) {
+        const auto filesIndexes = filesForIndexes(alist);
+        for (Archive::Entry *entry : filesIndexes) {
             const QString fullPath = entry->fullPath();
             if (!fullPathsList.contains(fullPath)) {
                 entry->rootNode = rootFileName;
@@ -1270,7 +1278,7 @@ void Part::slotAddFiles(const QStringList& filesToAdd, const Archive::Entry *des
     }
 
     QStringList withChildPaths;
-    foreach (const QString& file, filesToAdd) {
+    for (const QString& file : filesToAdd) {
         m_jobTempEntries.push_back(new Archive::Entry(nullptr, file));
         if (QFileInfo(file).isDir()) {
             withChildPaths << file + QLatin1Char('/');
@@ -1401,11 +1409,11 @@ void Part::slotCutFiles()
     m_model->filesToMove = ArchiveModel::entryMap(filesForIndexes(selectedRows));
     qCDebug(ARK) << "Entries marked to cut:" << m_model->filesToMove.values();
     m_model->filesToCopy.clear();
-    foreach (const QModelIndex &row, m_cutIndexes) {
+    for (const QModelIndex &row : qAsConst(m_cutIndexes)) {
         m_view->dataChanged(row, row);
     }
     m_cutIndexes = selectedRows;
-    foreach (const QModelIndex &row, m_cutIndexes) {
+    for (const QModelIndex &row : qAsConst(m_cutIndexes)) {
         m_view->dataChanged(row, row);
     }
     updateActions();
@@ -1415,7 +1423,7 @@ void Part::slotCopyFiles()
 {
     m_model->filesToCopy = ArchiveModel::entryMap(filesForIndexes(addChildren(getSelectedIndexes())));
     qCDebug(ARK) << "Entries marked to copy:" << m_model->filesToCopy.values();
-    foreach (const QModelIndex &row, m_cutIndexes) {
+    for (const QModelIndex &row : qAsConst(m_cutIndexes)) {
         m_view->dataChanged(row, row);
     }
     m_cutIndexes.clear();
@@ -1467,7 +1475,7 @@ void Part::slotPasteFiles()
             m_destination->setFullPath(m_destination->fullPath() + entryName);
         }
 
-        foreach (const Archive::Entry *entry, entriesWithoutChildren) {
+        for (const Archive::Entry *entry : qAsConst(entriesWithoutChildren)) {
             if (entry->isDir() && m_destination->fullPath().startsWith(entry->fullPath())) {
                 KMessageBox::error(widget(),
                                    i18n("Folders can't be moved into themselves."),
@@ -1544,12 +1552,14 @@ void Part::slotAddFilesDone(KJob* job)
 {
     qDeleteAll(m_jobTempEntries);
     m_jobTempEntries.clear();
-    if (job->error() && job->error() != KJob::KilledJobError) {
-        KMessageBox::error(widget(), job->errorString());
+    m_messageWidget->hide();
+    if (job->error()) {
+        if (job->error() != KJob::KilledJobError) {
+            KMessageBox::error(widget(), job->errorString());
+        } else if (isCreatingNewArchive()) {
+            resetArchive();
+        }
     } else {
-        // Hide the "archive will be created as soon as you add a file" message.
-        m_messageWidget->hide();
-
         // For multi-volume archive, we need to re-open the archive after adding files
         // because the name changes from e.g name.rar to name.part1.rar.
         if (m_model->archive()->isMultiVolume()) {
