@@ -61,7 +61,7 @@ LibzipPlugin::LibzipPlugin(QObject *parent, const QVariantList & args)
 
 LibzipPlugin::~LibzipPlugin()
 {
-    foreach (const auto e, m_emittedEntries) {
+    for (const auto e : qAsConst(m_emittedEntries)) {
         // Entries might be passed to pending slots, so we just schedule their deletion.
         e->deleteLater();
     }
@@ -70,7 +70,6 @@ LibzipPlugin::~LibzipPlugin()
 bool LibzipPlugin::list()
 {
     qCDebug(ARK) << "Listing archive contents for:" << QFile::encodeName(filename());
-    setOperationMode(List);
     m_numberOfEntries = 0;
 
     int errcode = 0;
@@ -116,7 +115,6 @@ bool LibzipPlugin::list()
 bool LibzipPlugin::addFiles(const QVector<Archive::Entry*> &files, const Archive::Entry *destination, const CompressionOptions& options, uint numberOfEntriesToAdd)
 {
     Q_UNUSED(numberOfEntriesToAdd)
-    setOperationMode(Add);
     int errcode = 0;
     zip_error_t err;
 
@@ -130,7 +128,7 @@ bool LibzipPlugin::addFiles(const QVector<Archive::Entry*> &files, const Archive
     }
 
     uint i = 0;
-    foreach (const Archive::Entry* e, files) {
+    for (const Archive::Entry* e : files) {
 
         if (QThread::currentThread()->isInterruptionRequested()) {
             break;
@@ -381,7 +379,6 @@ bool LibzipPlugin::emitEntryForIndex(zip_t *archive, qlonglong index)
 
 bool LibzipPlugin::deleteFiles(const QVector<Archive::Entry*> &files)
 {
-    setOperationMode(Delete);
     int errcode = 0;
     zip_error_t err;
 
@@ -395,7 +392,7 @@ bool LibzipPlugin::deleteFiles(const QVector<Archive::Entry*> &files)
     }
 
     qulonglong i = 0;
-    foreach (const Archive::Entry* e, files) {
+    for (const Archive::Entry* e : files) {
 
         if (QThread::currentThread()->isInterruptionRequested()) {
             break;
@@ -427,7 +424,6 @@ bool LibzipPlugin::deleteFiles(const QVector<Archive::Entry*> &files)
 
 bool LibzipPlugin::addComment(const QString& comment)
 {
-    setOperationMode(Comment);
     int errcode = 0;
     zip_error_t err;
 
@@ -457,7 +453,6 @@ bool LibzipPlugin::addComment(const QString& comment)
 bool LibzipPlugin::testArchive()
 {
     qCDebug(ARK) << "Testing archive";
-    setOperationMode(Test);
     int errcode = 0;
     zip_error_t err;
 
@@ -507,24 +502,12 @@ bool LibzipPlugin::testArchive()
 
 bool LibzipPlugin::doKill()
 {
-    QMutexLocker mutexLocker(&m_mutex);
-    switch (m_operationMode) {
-    case Add:
-    case Copy:
-    case Delete:
-    case Move:
-        return false;
-    default:
-        break;
-    }
-
-    return true;
+    return false;
 }
 
 bool LibzipPlugin::extractFiles(const QVector<Archive::Entry*> &files, const QString& destinationDirectory, const ExtractionOptions& options)
 {
     qCDebug(ARK) << "Extracting files to:" << destinationDirectory;
-    setOperationMode(Extract);
     const bool extractAll = files.isEmpty();
     const bool removeRootNode = options.isDragAndDropEnabled();
 
@@ -572,7 +555,7 @@ bool LibzipPlugin::extractFiles(const QVector<Archive::Entry*> &files, const QSt
     } else {
         // We extract only the entries in files.
         qulonglong i = 0;
-        foreach (const Archive::Entry* e, files) {
+        for (const Archive::Entry* e : files) {
             if (QThread::currentThread()->isInterruptionRequested()) {
                 break;
             }
@@ -796,7 +779,6 @@ bool LibzipPlugin::extractEntry(zip_t *archive, const QString &entry, const QStr
 bool LibzipPlugin::moveFiles(const QVector<Archive::Entry*> &files, Archive::Entry *destination, const CompressionOptions &options)
 {
     Q_UNUSED(options)
-    setOperationMode(Move);
     int errcode = 0;
     zip_error_t err;
 
@@ -846,7 +828,6 @@ bool LibzipPlugin::moveFiles(const QVector<Archive::Entry*> &files, Archive::Ent
 bool LibzipPlugin::copyFiles(const QVector<Archive::Entry*> &files, Archive::Entry *destination, const CompressionOptions &options)
 {
     Q_UNUSED(options)
-    setOperationMode(Copy);
     int errcode = 0;
     zip_error_t err;
 
@@ -977,10 +958,4 @@ QString LibzipPlugin::permissionsToString(const mode_t &perm)
     return modeval;
 }
 
-void LibzipPlugin::setOperationMode(ReadWriteArchiveInterface::OperationMode operationMode)
-{
-    QMutexLocker mutexLocker(&m_mutex);
-    m_operationMode = operationMode;
-}
-
 #include "libzipplugin.moc"
